<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="203"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>MX USB Unmounter</source>
        <translation>MX Smonta USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="52"/>
        <source>Double-Click to Unmount</source>
        <translation>Doppio-Click per smontare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>No Removable Device</source>
        <translation>Nessun Dispositivo Rimovibile</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>Other partitions still mounted on device</source>
        <translation>Altre partizioni ancora montate sul dispositivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Unmounting %1</source>
        <translation>Smontaggio %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>%1 is Safe to Remove</source>
        <translation>%1 può essere rimosso in modo sicuro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Unable to unmount, device in use</source>
        <translation>Impossibile smontare, dispositivo in uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>List Devices</source>
        <translation>Elenca i dispositivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Always show icon</source>
        <translation>Mostra sempre l&apos;icona</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Hide icon when not in use</source>
        <translation>Nascondi l&apos;icona quando non è in uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Autostart has been disabled.</source>
        <translation>L&apos;avvio automatico è stato disabilitato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>Failed to disable autostart.</source>
        <translation>Impossibile disabilitare l&apos;avvio automatico.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>Autostart Disabled</source>
        <translation>Avvio automatico disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Enable Autostart</source>
        <translation>Abilita l&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Autostart has been enabled.</source>
        <translation>L&apos;avvio automatico è stato abilitato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Failed to enable autostart.</source>
        <translation>Impossibile abilitare l&apos;avvio automatico.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Autostart Enabled</source>
        <translation>Avvio automatico abilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>Disable Autostart</source>
        <translation>Disabilita l&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Unmount</source>
        <translation>Smonta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>About MX USB Unmounter</source>
        <translation>Informazioni su MX Smonta USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Quickly Unmount Removable Media</source>
        <translation>Smontaggio rapido di unità rimovibili</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Application icon will stay visible all the time.</source>
        <translation>L&apos;icona dell&apos;applicazione rimarrà visibile per tutto il tempo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Application icon is now hidden and will reappear when a new device is connected.</source>
        <translation>L&apos;icona dell&apos;applicazione è ora nascosta e riapparirà quando verrà connesso un nuovo dispositivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Application icon will be hidden when there are no devices plugged in.</source>
        <translation>L&apos;icona dell&apos;applicazione verrà nascosta quando non ci sono dispositivi collegati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Icon Visibility</source>
        <translation>Visibilità dell&apos;icona</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
</TS>
